Extracts and returns the training history from a parsnip model_fit object
created by kerasnip.
Value
A keras_training_history object. You can call plot() on this
object to visualize the learning curves.
Extracts and returns the training history from a parsnip model_fit object
created by kerasnip.
A keras_training_history object. You can call plot() on this
object to visualize the learning curves.