This is an internal helper function to retrieve the environment where
parsnip stores its model definitions. It is used to dynamically
interact with the parsnip infrastructure.
This is an internal helper function to retrieve the environment where
parsnip stores its model definitions. It is used to dynamically
interact with the parsnip infrastructure.