glance.kerasnip_model_fit: Glance at a Fitted Kerasnip Model

View source: R/keras_tools.R

glance.kerasnip_model_fitR Documentation

Glance at a Fitted Kerasnip Model

Description

Returns a one-row tibble of summary statistics from the final training epoch: every metric the model was compiled with (e.g. loss, accuracy).

Usage

## S3 method for class 'kerasnip_model_fit'
glance(x, ...)

Arguments

x

A kerasnip_model_fit object.

...

Not used.

Value

A one-row tibble with one column per compiled metric. Returns an empty tibble if training history has been stripped (e.g. by butcher).


kerasnip documentation built on Sept. 4, 2026, 1:06 a.m.