These exported vectors contain the names of optimizers, losses, and metrics
discovered from the installed keras3 package when kerasnip is loaded.
This ensures that kerasnip is always up-to-date with your Keras version.
Details
These objects are primarily used to provide the default values for the
dials parameter functions, optimizer_function() and
loss_function_keras(). This allows for tab-completion in IDEs and
validation of optimizer and loss names when tuning models.
The discovery process in .onLoad() scrapes the keras3 namespace for
functions matching optimizer_*, loss_*, and metric_* patterns.