Allows users to register a custom loss function so it can be used by name
within kerasnip model specifications and tuned with dials.
Allows users to register a custom loss function so it can be used by name
within kerasnip model specifications and tuned with dials.