View source: R/step_collapse.R
| step_collapse | R Documentation |
step_collapse() creates a a specification of a recipe step that will
convert a group of predictors into a single list-column. This is useful
for custom models that need the predictors in a different format.
step_collapse(
recipe,
...,
role = "predictor",
trained = FALSE,
columns = NULL,
new_col = "predictor_matrix",
skip = FALSE,
id = recipes::rand_id("collapse")
)
recipe |
A recipe object. The step will be added to the sequence of operations for this recipe. |
... |
One or more selector functions to choose which variables are
affected by the step. See |
role |
For model terms created by this step, what analysis role should they be assigned?. By default, the new columns are used as predictors. |
trained |
A logical to indicate if the quantities for preprocessing have been estimated. |
columns |
A character string of the selected variable names. This is
|
new_col |
A character string for the name of the new list-column. The default is "predictor_matrix". |
skip |
A logical. Should the step be skipped when the recipe is
baked by |
id |
A character string that is unique to this step to identify it. |
An updated version of recipe with the new step added to the
sequence of existing steps (if any). For the tidy method, a tibble with
columns terms which is the columns that are affected and value which is
the type of collapse.
library(recipes)
# 2 predictors
dat <- data.frame(
x1 = 1:10,
x2 = 11:20,
y = 1:10
)
rec <- recipe(y ~ ., data = dat) %>%
step_collapse(x1, x2, new_col = "pred") %>%
prep()
bake(rec, new_data = NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.