| extract_keras_history | R Documentation |
Extracts and returns the training history from a parsnip model_fit object
created by kerasnip.
extract_keras_history(object)
object |
A |
Extract Keras Training History
The history object contains the metrics recorded during model training, such as loss and accuracy, for each epoch. This is highly useful for visualizing the training process and diagnosing issues like overfitting. The returned object can be plotted directly.
A keras_training_history object. You can call plot() on this
object to visualize the learning curves.
keras_evaluate, extract_keras_model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.