| extract_keras_model | R Documentation |
Extracts and returns the underlying Keras model object from a parsnip
model_fit object created by kerasnip.
extract_keras_model(object)
object |
A |
Extract the Raw Keras Model from a Kerasnip Fit
This is useful when you need to work directly with the Keras model object for tasks like inspecting layer weights, creating custom plots, or passing it to other Keras-specific functions.
The raw Keras model object (keras_model).
keras_evaluate, extract_keras_history
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.