Learn R Programming

kerasnip (version 0.1.0)

get_model_env: Get Parsnip's Model Environment

Description

This is an internal helper function to retrieve the environment where parsnip stores its model definitions. It is used to dynamically interact with the parsnip infrastructure.

Usage

get_model_env()

Arguments

Value

The parsnip model environment.

Examples

Run this code
# \donttest{
model_env <- kerasnip::get_model_env()
# }

Run the code above in your browser using DataLab