powered by
This is an internal helper function to retrieve the environment where parsnip stores its model definitions. It is used to dynamically interact with the parsnip infrastructure.
parsnip
get_model_env()
The parsnip model environment.
# \donttest{ model_env <- kerasnip::get_model_env() # }
Run the code above in your browser using DataLab