| glance.kerasnip_model_fit | R Documentation |
Returns a one-row tibble of summary statistics from the final training epoch:
every metric the model was compiled with (e.g. loss, accuracy).
## S3 method for class 'kerasnip_model_fit'
glance(x, ...)
x |
A |
... |
Not used. |
A one-row tibble with one column per compiled metric. Returns an empty tibble if training history has been stripped (e.g. by butcher).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.