Allows users to register a custom loss function so it can be used by name
within kerasnip model specifications and tuned with dials.
register_keras_loss(name, loss_fn)No return value, called for side effects.
The name to register the loss under (character).
The loss function.
Registered losses are stored in an internal environment. When a model is
compiled, kerasnip will first check this internal registry for a loss
matching the provided name before checking the keras3 package.
register_keras_optimizer(), register_keras_metric()