| tidy.kerasnip_model_fit | R Documentation |
Returns a tibble with one row per layer of the underlying Keras model, summarising the layer name, Python class, and parameter count.
## S3 method for class 'kerasnip_model_fit'
tidy(x, ...)
x |
A |
... |
Not used. |
A tibble with columns layer (character), class (character),
and n_params (integer).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.